@@ -3,6 +3,7 @@ package main
 import (
 	"github.com/spf13/cobra"
 
+	u "github.com/lxc/incus/v6/cmd/incus/usage"
 	"github.com/lxc/incus/v6/internal/i18n"
 	cli "github.com/lxc/incus/v6/shared/cmd"
 )
@@ -14,7 +15,7 @@ type cmdWebui struct {
 // Command is a method of the cmdWebui structure that returns a new cobra Command for displaying resource usage per instance.
 func (c *cmdWebui) Command() *cobra.Command {
 	cmd := &cobra.Command{}
-	cmd.Use = cli.Usage("webui", i18n.G("[<remote>:]"))
+	cmd.Use = cli.U("webui", u.RemoteColonOpt)
 	cmd.Short = i18n.G("Open the web interface")
 	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G(
 		`Open the web interface`))
